@@ -28,6 +28,9 @@ requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
 
 logging.basicConfig(format=' %(message)s')
 
+
+netmiko_logger = logging.getLogger("paramiko")
+netmiko_logger.setLevel(logging.INFO)
 class dyagram:
 
     def __init__(self, inventory_file=None, verbose=False):
@@ -256,8 +259,9 @@ class dyagram:
 
         # CONN_SET = False
         try:
-
+            self.log.info(f"DEVICE: {device} - SSH : GETTING DEVICE TYPE : discover_routes_ssh")
             os = self.get_device_type(device)
+            self.log.info(f"DEVICE: {device} - SSH : GOT DEVICE TYPE : discover_routes_ssh")
 
             netmiko_args = {"device_type": os,
                             "host": device,
@@ -307,8 +311,9 @@ class dyagram:
 
             # if not CONN_SET:
             #     dev = ConnectHandler(**netmiko_args)
-
+            self.log.info(f"DEVICE: {device} - SSH : CREATING NETMIKO OBJ : discover_routes_ssh")
             dev = ConnectHandler(**netmiko_args)
+            self.log.info(f"DEVICE: {device} - SSH : CREATED NETMIKO OBJ : discover_routes_ssh")
             dev.enable()
 
             routes = dev.send_command("show ip route vrf all", use_textfsm=True)
@@ -339,9 +344,13 @@ class dyagram:
             autodetect_tries = 0
             while autodetect_tries < 10:
                 try:
-
+                    print(f"BEFORE GUESSOR")
                     guesser = SSHDetect(**autodetect_netmiko_args)
+                    print("AFTER GUESSOR")
+                    print("BEFORE BEST MATCH")
                     best_match = guesser.autodetect()
+                    print("AFTER BEST MATCH")
+
                     return best_match
 
 
@@ -350,7 +359,7 @@ class dyagram:
                     return None
 
                 except:
-
+                    print("HIT EXCEPT IN AUTODETECT")
                     if autodetect_tries > 10:
                         tb = self.get_traceback()
                         self.log.info(f"DEVICE: {device} EXCEPTION THROWN IN GET_DEVICE_TYPE: {tb}")
@@ -421,7 +430,6 @@ class dyagram:
 
         try:
             self.log.info("GETTING DEVICE TYPE IN EIGRP NEIGHBORS SSH")
-            time.sleep(10)
             os = self.get_device_type(device)
             self.log.info("GOT DEVICE TYPE  FROM get_device_type func IN EIGRP NEIGHBORS SSH_top")
             if os:
@@ -439,9 +447,9 @@ class dyagram:
                 #raise Exception("Unable to determine OS.")
                 self.log.info("GOT DEVICE TYPE IN EIGRP NEIGHBORS SSH")
 
-            self.log.info("CREATING NETMIKO OBJ IN EIGRP NEIGHBORS SSH")
+            self.log.info("CREATING NETMIKO OBJ : discover_eigrp_neighbors_ssh")
             dev = ConnectHandler(**nm_args)
-            self.log.info("CREATED NETMIKO OBJ IN EIGRP NEIGHBORS SSH")
+            self.log.info("CREATED NETMIKO OBJ : discover_eigrp_neighbors_ssh")
 
             dev.enable()
 
@@ -524,16 +532,15 @@ class dyagram:
     def _discover_lldp_neighbors_by_ssh(self, device):
 
         try:
-            self.log.info(f"DEVICE: {device} - SSH : STARTING MODULE: _discover_lldp_neighbors_by_ssh")
-
+            self.log.info(f"DEVICE: {device} - SSH : GETTING DEVICE TYPE : _discover_lldp_neighbors_by_ssh")
             os = self.get_device_type(device)
-
+            self.log.info(f"DEVICE: {device} - SSH : GOT DEVICE TYPE : _discover_lldp_neighbors_by_ssh")
             netmiko_args = {"device_type": os,
                             "host": device,
                             "username": self.username,
                             "password": self.password,
                             "secret": self.password,
-                            "banner_timeout": 200}
+                            }
 
 
                 # try:
@@ -551,9 +558,9 @@ class dyagram:
                 # os = self._get_os_version(dev)
                 # netmiko_args['device_type'] = os
 
-
+            self.log.info(f"DEVICE: {device} - SSH : CREATING NETMIKO OBJ : _discover_lldp_neighbors_by_ssh")
             dev = ConnectHandler(**netmiko_args)
-
+            self.log.info(f"DEVICE: {device} - SSH : CREATED NETMIKO OBJ : _discover_lldp_neighbors_by_ssh")
             self.log.info(f"DEVICE: {device} - SSH : SETTING ENABLE")
 
             dev.enable()
@@ -922,5 +929,7 @@ def main():
 
 
 if __name__ == "__main__":
+    netmiko_logger = logging.getLogger("paramiko")
+    netmiko_logger.setLevel(logging.INFO)
     main()
 
